summaryrefslogtreecommitdiff
path: root/Source/SaveBitMap.S
diff options
context:
space:
mode:
authorChristian A. Weber <chris@gna.ch>1992-05-15 03:21:10 +0000
committerChristian A. Weber <chris@gna.ch>1992-05-15 03:21:10 +0000
commite556b972d1ad64453b3372b486191e2a59c91dda (patch)
tree4eb9264758c36cc75cdcf8daf8dde1517d77cb6a /Source/SaveBitMap.S
parent36c824864c02f0a3f62c8a1d365d1670835c8c96 (diff)
downloadiff-library-e556b972d1ad64453b3372b486191e2a59c91dda.tar.gz
iff-library-e556b972d1ad64453b3372b486191e2a59c91dda.tar.bz2
iff-library-e556b972d1ad64453b3372b486191e2a59c91dda.zip
An neue Include-Files angepasst
Diffstat (limited to 'Source/SaveBitMap.S')
-rw-r--r--Source/SaveBitMap.S28
1 files changed, 14 insertions, 14 deletions
diff --git a/Source/SaveBitMap.S b/Source/SaveBitMap.S
index 15607c3..91fc2c9 100644
--- a/Source/SaveBitMap.S
+++ b/Source/SaveBitMap.S
@@ -1,13 +1,13 @@
**
-** $Id: $
-** $Revision: $
+** $Id: SaveBitMap.S,v 1.1 92/05/12 22:26:54 chris Exp $
+** $Revision: 1.1 $
**
** $Filename: SaveBitMap.S $
-** $Author: Christian A. Weber $
+** $Author: chris $
** $Release: 19.1 $
-** $Date: 92/05/11 21:11:27 $
+** $Date: 92/05/12 22:26:54 $
**
-** iff.library/IFFLib_SaveBitMap
+** iff.library/IFFL_SaveBitMap
**
** COPYRIGHT (C) 1987-1992 BY CHRISTIAN A. WEBER, BRUGGERWEG 2,
** CH-8037 ZUERICH, SWITZERLAND. ALL RIGHTS RESERVED. NO PART
@@ -17,7 +17,7 @@
**
- IDNT IFFLib_SaveBitMap
+ IDNT IFFL_SaveBitMap
SECTION text,CODE
INCLUDE "IFFLib.i"
@@ -26,16 +26,16 @@
XDEF SaveBitMapFunc
-******* iff.library/IFFLib_SaveBitMap ***************************************
+******* iff.library/IFFL_SaveBitMap *****************************************
*
* NAME
* IFFLib_SaveBitMap -- save the planes of a BitMap as an IFF-file
*
* SYNOPSIS
-* result = IFFLib_SaveBitMap( filename, bitmap, colortable, flags )
-* D0 A0 A1 A2 D0
+* result = IFFL_SaveBitMap( filename, bitmap, colortable, flags )
+* D0 A0 A1 A2 D0
*
* BOOL IFFLib_SaveBitMap(char *, struct BitMap *, UWORD *, ULONG )
*
* FUNCTION
* Save the planes of a BitMap as an IFF-file, optionally with a
@@ -59,14 +59,14 @@
* 0 = This is a normal or Extra-Halfbrite picture
*
* RESULT
* Non-zero if successful, 0 if error, Call IFFLib_IFFError() to know
* more about the reason of the failure
*
* NOTE
-* This routine needs 620 bytes of stack space
+* This routine needs 650 bytes of stack space
*
* SEE ALSO
-* SaveClip
+* IFFL_SaveClip()
*
*****************************************************************************
@@ -26,16 +26,16 @@
*
* NAME
-* IFFLib_SaveBitMap -- save the planes of a BitMap as an IFF-file
+* IFFL_SaveBitMap -- save the planes of a BitMap as an IFF-file
*
* SYNOPSIS
@@ -26,16 +26,16 @@
*
-* BOOL IFFLib_SaveBitMap(char *, struct BitMap *, UWORD *, ULONG )
+* BOOL IFFL_SaveBitMap(char *, struct BitMap *, UWORD *, ULONG )
*
* FUNCTION
@@ -59,14 +59,14 @@
*
* RESULT
-* Non-zero if successful, 0 if error, Call IFFLib_IFFError() to know
+* Non-zero if successful, 0 if error, Call IFFL_IFFError() to know
* more about the reason of the failure
*